@@ -3,6 +3,7 @@
 #![deny(clippy::panic)]
 
 use anyhow::{anyhow, bail, ensure, Context, Result};
+use cargo_metadata::MetadataCommand;
 use dylint_internal::env::{self, var};
 use lazy_static::lazy_static;
 use std::{
@@ -46,6 +47,7 @@ pub type NameToolchainMap = BTreeMap<String, ToolchainMap>;
 pub struct Dylint {
     pub all: bool,
     pub isolate: bool,
+    pub keep_going: bool,
     pub libs: Vec<String>,
     pub list: bool,
     pub manifest_path: Option<String>,
@@ -427,10 +429,14 @@ fn check(
 ) -> Result<()> {
     let clippy_disable_docs_links = clippy_disable_docs_links()?;
 
+    let mut failures = Vec::new();
+
     for (toolchain, paths) in resolved {
+        let target_dir = target_dir(opts, toolchain)?;
+        let target_dir_str = target_dir.to_string_lossy();
         let driver = driver_builder::get(opts, toolchain)?;
         let dylint_libs = serde_json::to_string(&paths)?;
-        let mut args = vec![];
+        let mut args = vec!["--target-dir", &target_dir_str];
         if let Some(path) = &opts.manifest_path {
             args.extend(&["--manifest-path", path]);
         }
@@ -450,7 +456,7 @@ fn check(
         // https://github.com/rust-lang/rust-clippy/commit/1a206fc4abae0b57a3f393481367cf3efca23586
         // But I am going to continue to set CLIPPY_DISABLE_DOCS_LINKS because it doesn't seem to
         // hurt and it provides a small amount of backward compatibility.
-        dylint_internal::check()
+        let result = dylint_internal::check()
             .envs(vec![
                 (
                     env::CLIPPY_DISABLE_DOCS_LINKS.to_owned(),
@@ -464,10 +470,38 @@ fn check(
                 (env::RUSTUP_TOOLCHAIN.to_owned(), toolchain.clone()),
             ])
             .args(args)
-            .success()?;
+            .success();
+        if result.is_err() {
+            if !opts.keep_going {
+                return result
+                    .with_context(|| format!("Compilation failed with toolchain `{}`", toolchain));
+            };
+            failures.push(toolchain);
+        }
     }
 
-    Ok(())
+    if failures.is_empty() {
+        Ok(())
+    } else {
+        Err(anyhow!(
+            "Compilation failed with the following toolchains: {:?}",
+            failures
+        ))
+    }
+}
+
+fn target_dir(opts: &Dylint, toolchain: &str) -> Result<PathBuf> {
+    let mut command = MetadataCommand::new();
+    if let Some(path) = &opts.manifest_path {
+        command.manifest_path(path);
+    }
+    let metadata = command.no_deps().exec()?;
+    Ok(metadata
+        .target_directory
+        .join("dylint")
+        .join("target")
+        .join(toolchain)
+        .into())
 }
 
 fn flatten_toolchain_map(toolchain_map: &ToolchainMap) -> Vec<(String, PathBuf)> {
